.. -*-restructuredtext-*-

.. image:: https://github.com/ubernostrum/akismet/workflows/CI/badge.svg
   :alt: CI status image
   :target: https://github.com/ubernostrum/akismet/actions?query=workflow%3ACI

``akismet`` is a Python library wrapping `the Wordpress Akismet
spam-detection service <https://akismet.com/>`_. All methods of the
Akismet API are supported:

* Checking comments for spam

* Reporting comments incorrectly classified as not spam

* Reporting comments incorrectly classified as spam

Use of this module requires an Akismet API key (which must be obtained
from the Akismet service).

The Python ``akismet`` module was originally written by Michael Foord.

Full documentation is `available online <http://akismet.readthedocs.io/>`_.